@@ -290,8 +290,8 @@ def overall_report(limit: int = 0):
 @transaction.atomic()
 def process_member(member_id):
     """Process a member"""
-    SAMPLES_BUCKET = "samples-crossref-research"
-    SAMPLES_PATH = "members-works/sample-2023-01-21/works/"
+    SAMPLES_BUCKET = "samples.research.crossref.org"
+    SAMPLES_PATH = "members-works/2023-03-05/samples/"
 
     ANNOTATION_BUCKET = "outputs.research.crossref.org"
     ANNOTATION_PATH = "annotations"
@@ -311,7 +311,7 @@ def process_member(member_id):
         SAMPLES_PATH,
         member_id,
         CODE_BUCKET,
-        verbose=True,
+        verbose=False,
     )
 
 
