@@ -1,3 +1,4 @@
+import hashlib
 import json
 import logging
 import os
@@ -8,8 +9,8 @@ from typing import DefaultDict, Any
 
 from crossref.restful import MaxOffsetError
 
-SAMPLES_BUCKET = "samples-crossref-research"
-SAMPLES_PATH = "members-works/sample-2023-01-21/works/"
+SAMPLES_BUCKET = "samples.research.crossref.org"
+SAMPLES_PATH = "members-works/2023-03-05/samples/"
 
 ANNOTATION_BUCKET = "outputs.research.crossref.org"
 ANNOTATION_PATH = "annotations"
@@ -218,6 +219,7 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
         result = json.loads(sample_item)["data-point"]
 
         overall_status["about"]["member"] = result["member"]
+        overall_status["unpreserved-items"] = list()
 
         # we can only work with journal articles
         # we exclude journal articles from the current year because they
@@ -236,6 +238,19 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
 
                 preservation_statuses, doi = preservation_status(result)
 
+                md5_doi = hashlib.md5(doi["DOI"].lower().encode())
+                key = f"{ANNOTATION_PATH}/works/{md5_doi}/{ANNOTATION_FILENAME}"
+
+                session = boto3.Session()
+                s3 = session.resource("s3")
+
+                push_json_to_s3(
+                    s3=s3,
+                    json_obj=preservation_statuses,
+                    bucket=ANNOTATION_BUCKET,
+                    path=key,
+                )
+
                 # increment the sample count
                 overall_status["sample-count"] += 1
 
@@ -270,6 +285,8 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
                 else:
                     overall_status["unpreserved-count"] += 1
 
+                    overall_status["unpreserved-items"].append(doi["DOI"])
+
                     if verbose:
                         logging.info(f"{doi['DOI']} has no preservation")
                         logging.info(
@@ -401,17 +418,20 @@ def process_sample(
     """
     import logging
 
+    # the environment setup is needed for logging etc. because of the
+    # joblib parallelization
+    import environment
+
+    environment.setup_environment(code_bucket, download_settings=False)
+
     import boto3
 
     s3client = boto3.client("s3")
     session = boto3.Session()
     s3 = session.resource("s3")
 
-    import environment
-
-    environment.setup_environment(code_bucket, download_settings=False)
-
-    logging.info(f"Processing member {member_id}")
+    if verbose:
+        logging.info(f"Processing member {member_id}")
 
     samples = get_samples(
         s3client,
@@ -439,6 +459,7 @@ def process_sample(
 def generate_report(resume_from: int):
     import boto3
     import logging
+    from rich.progress import track
 
     s3client = boto3.client("s3")
 
@@ -474,7 +495,7 @@ def generate_report(resume_from: int):
             member_id,
             CODE_BUCKET,
         )
-        for member_id in members
+        for member_id in track(members)
     )
 
     return members
